/*******************************************************

		translate.h

   declarations for external variables and functions
   from translate.c.

********************************************************/


#define SAVEPOINT 0
#define RECURSE 1

#define STARTAG 19
#define MEASTAG 18

#define DEFAULTNAME "a point"

#define NO_CABLE_CHECK  1

/* structure for a data point for rotation correction calculations */

struct rotPoint{
   
   struct rotPoint *nextPoint;  /* This will be a linked list. */

   int id;			/* id number used for selecting points */
   char pointName[32];		/* a text name for convenience */

   struct aPoint starLoc;	/* Where we think star should be */
   struct aPoint measLoc;  /* Where star actually is */
};


/* structure for a pair of rotation points used to generate a 
   rotation angle */

struct rotPair{

   struct rotPair *nextPair;

   int id;			/* id number used for selecting pairs */
   char pairName[128];		/* a text name for convenience */

   struct rotPoint *point1;	/* first data point */
   struct rotPoint *point2;	/* second data point */

   double rotAngle;		/* rotation angle based on this pair */

   double rSep2;		/* radius (squared) between calculated
  				   position. of the two stars in the pair. */
};


/* structure for rotation statistics */

struct rotStats{

   struct rotPoint *nextPoint;	/* list of data points */

   struct rotPair  *nextPair;	/* list of data points */

   int numberOfPairs;

   double sumAngles;

   double sumWeights;

   double workingAngle;		/* angle used in calculations */

   double aveAngle;		/* angle currently in use */

   double defaultAngle;		/* angle currently in use */
};


extern struct rotStats RotData; /*  rotation statistics and point list */
extern double Theta;		/*  global for coordinate system rotation */
extern int Rotflag;		/*  global flag to enable coordinate rotation */

extern double Hangle;		/*  global for hour angle (decimal hours) */


extern  void initRotation();
 
extern  void addRotationPt();
 
extern  void listRotationPts();
extern  void listRotationPrs();
 
extern  void clearRotationPt();
extern  void clearRotationPr();
 
extern  double calcRotation();
extern  void calculatePairs();

double radToDeg();
double degToRad();
